table {
    border-collapse: collapse;
    width: 100%;
}
td {
    text-align: left;
    padding: 8px;
}

tr:nth-child(even){background-color: lightgray}

th {
    background-color: #4CAF50;
    color: white;
}

tr:hover {background-color: gray}
