

span.ansiblack {color: #343d46;}
span.ansiblue {color: #96b5b4;}
span.ansigray {color: #a7adba;}
span.ansigreen {color: #a3be8c;}
span.ansipurple {color: #b48ead;}
span.ansired {color: #bf616a;}
span.ansiyellow {color: #ebcb8b;}

div.output_stderr {background-color: #bf616a;}
div.output_stderr pre {color: #dfe1e8;}

.cm-s-ipython.CodeMirror {background: #2b303b; color: #dfe1e8;}
.cm-s-ipython div.CodeMirror-selected {background: #343d46 !important;}
.cm-s-ipython .CodeMirror-gutters {background: #2b303b; border-right: 0px;}
.cm-s-ipython .CodeMirror-linenumber {color: #65737e;}
.cm-s-ipython .CodeMirror-cursor {border-left: 1px solid #a7adba !important;}

.cm-s-ipython span.cm-comment {color: #ab7967;}
.cm-s-ipython span.cm-atom {color: #b48ead;}
.cm-s-ipython span.cm-number {color: #b48ead;}

.cm-s-ipython span.cm-property, .cm-s-ipython span.cm-attribute {color: #a3be8c;}
.cm-s-ipython span.cm-keyword {color: #bf616a;}
.cm-s-ipython span.cm-string {color: #ebcb8b;}
.cm-s-ipython span.cm-operator {color: #ab7967;}
.cm-s-ipython span.cm-builtin {color: #b48ead;}

.cm-s-ipython span.cm-variable {color: #a3be8c;}
.cm-s-ipython span.cm-variable-2 {color: #8fa1b3;}
.cm-s-ipython span.cm-def {color: #d08770;}
.cm-s-ipython span.cm-error {background: #bf616a; color: #a7adba;}
.cm-s-ipython span.cm-bracket {color: #c0c5ce;}
.cm-s-ipython span.cm-tag {color: #bf616a;}
.cm-s-ipython span.cm-link {color: #b48ead;}

.cm-s-ipython .CodeMirror-matchingbracket { text-decoration: underline; color: #dfe1e8 !important;}
